@@ -1,7 +1,7 @@
 <?php
 
 /*
- * forward:  $Id: lib.php,v 1.3 2003/04/11 23:59:59 shaug Exp $
+ * forward:  $Id: lib.php,v 1.6 2003/06/28 00:29:52 shaug Exp $
  * (c) 2002 O'Shaughnessy Evans <shaug-spamrule @ wumpus.org>
  */
 
@@ -238,7 +238,7 @@ function ar_ftp_put($path, $data)
             return array(FALSE, "error removing $path: $php_errormsg");
     }
 
-    ftp_close($ftp);
+    @ftp_close($ftp);
     fclose($temp);
 
     return array(TRUE);
@@ -290,18 +290,18 @@ function ar_change_autoresponse()
 
             // if it looks like a disabled forward that we created
             // earlier, remember it as the default forward address
-            if (ereg('^# forward: *([^ ].*)', $f, $regs)) {
+            if (@ereg('^# forward: *([^ ].*)', $f, $regs)) {
                 array_push($addrs, $regs[1]);
             }
             // skip other comments
-            else if (ereg('^#', $f)) {
+            else if (@ereg('^#', $f)) {
                 continue;
             }
             // if the forward entry is a path,
             // either it's being put into the Trash or
             // we will presume that means a local copy is being kept
-            else if (ereg('^([\.\/\\][^ ]*)', $f, $regs)) {
-                if (ereg("$trash_folder$", $regs[1])) {
+            else if (@ereg('^([\.\/\\][^ ]*)', $f, $regs)) {
+                if (@ereg("$trash_folder$", $regs[1])) {
                     $check_trash = 'checked';
                 }
                 else {
@@ -312,17 +312,17 @@ function ar_change_autoresponse()
             }
             // if it matches our vacation regex, turn on
             // the checked flag for the form
-            else if (ereg($AUTORESPOND_OPTS['vacation_pattern'], $f)) {
+            else if (@ereg($AUTORESPOND_OPTS['vacation_pattern'], $f)) {
                 $check_vacation = 'checked';
             }
             // if it matches our filter command pattern, turn on the
             // keep checkbox and the filter option
-            else if (ereg($AUTORESPOND_OPTS['filter_pattern'], $f)) {
+            else if (@ereg($AUTORESPOND_OPTS['filter_pattern'], $f)) {
                 $keep_filt = $check_keep = 'checked';
                 $keep_nofilt = '';
             }
             // ignore other pipes
-            else if (ereg('^|', $f)) {
+            else if (@ereg('^\"?\|', $f)) {
                 continue;
             }
             // finally, if the line matches anything else, we presume
@@ -392,12 +392,12 @@ EOvacation;
     // show the "keep a local copy" checkboxes
     $desc = $AUTORESPOND_OPTS['keep_desc'];
     $keep_text = isset($AUTORESPOND_OPTS['filter_string'])
-     ? "<br><br>\n".
+     ? '&nbsp;&nbsp;'. $AUTORESPOND_OPTS['keep_filt_desc']. "<br><br>\n".
        '<input type=radio name=keeptype value=unfiltered '. $keep_nofilt. '>'.
        '<i>unfiltered</i>&nbsp;&nbsp;'. "\n".
        '<input type=radio name=keeptype value=filtered '. $keep_filt. '>'.
        '<i>filtered</i>'. "\n"
-     : '&nbsp;';
+     : "&nbsp;\n";
     echo <<<EOkeep
 <tr align=left valign=top bgcolor="{$color[4]}">
   <td><input type=checkbox name=keep $check_keep></td>
@@ -469,7 +469,7 @@ function ar_install_autoresponse()
 	sqgetGlobalVar('message', $vmesg);
         $vacdata = "Subject: ". $vsubj. "\n\n". $vmesg;
         $vacdata = str_replace("\r\n", "\n", $vacdata);
-        if (! ereg("\n$", $vacdata))
+        if (! @ereg("\n$", $vacdata))
             $vacdata .= "\n";
         list($stat, $ftpmesg) = ar_ftp_put($AUTORESPOND_OPTS['vacation_file'],
          $vacdata);
@@ -497,7 +497,7 @@ function ar_install_autoresponse()
                 $mesg .= "<br>\n... filtered through ".
                          $AUTORESPOND_OPTS['filter_descr']. '.';
         }
-        else if ($keeptype === 'unfiltered') {
+        else {
             $data = $AUTORESPOND_OPTS['keep_string']. "\n" . $data;
             if ($addr)
                 $mesg .= "<br>\nLocal copies will also be kept.";
@@ -505,9 +505,9 @@ function ar_install_autoresponse()
     }
 
     if ($trash) {
-        $trash = ereg('^[\.\/\\]', $trash_folder) ? $trash_folder
+        $trash = @ereg('^[\.\/\\]', $trash_folder) ? $trash_folder
                  : "./$trash_folder";
-        $mesg .= "<br>\nMail will be kept in your Trash mailbox ($trash).";
+        $mesg .= "<br>\nMail will be kept in your Trash mailbox.";
         $data .= $trash. "\n";
     }
 
@@ -540,11 +540,11 @@ function ar_read_vacation()
     if ($status === TRUE && !empty($vacation)) {
         // if the vacation entry looks like an email Subject,
         // save it for the default
-        if (ereg('^Subject: (.*)', $vacation[0], $regs)) {
+        if (@ereg('^Subject: (.*)', $vacation[0], $regs)) {
             $subject = $regs[1];
             array_shift($vacation);
             reset($vacation);
-            if (ereg("^\r?\n?$", $vacation[0]))
+            if (@ereg("^\r?\n?$", $vacation[0]))
                 array_shift($vacation);
         }
         $message = implode('', $vacation);
@@ -565,7 +565,7 @@ function ar_edit_vacation()
     if (!$subject && !$message)
         list($subject, $message) = ar_read_vacation();
     else {
-        if (! ereg("\n$", $message))
+        if (! @ereg("\n$", $message))
             $message .= "\n";
         $data = "Subject: ". $subject. "\n\n". $message;
         $data = str_replace("\r\n", "\n", $data);
